import {NzModalSubject} from 'ng-zorro-antd';
import {Component, OnInit} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {environment} from '../../../../../environments/environment';
import {FormGroup, FormBuilder, FormControl, Validators} from '@angular/forms';

@Component({
  selector: 'app-account-edit',
  templateUrl: './account-edit.component.html',
  styles: []
})
export class AccountEditComponent implements OnInit {

  account: any;
  validateForm: FormGroup;
  searchOptions = [];

  constructor(
    private subject: NzModalSubject,
    public http: HttpClient,
    private formBuilder: FormBuilder
  ) {

  }

  ngOnInit() {
    this.validateForm = this.formBuilder.group({
      accountName: [this.account.accountName],
      mobile: [this.account.mobile],
      email: [this.account.email],
      weixin: [this.account.weixin],
      organizationId: [this.account.organizationId],
      expireTime: [this.account.expireTime],
      id: [this.account.id]
    });
    this.searchOptions = this.account.organization ? [this.account.organization] : [];
  }

  save() {
    if (this.validateForm.valid) {
      for (const i in this.validateForm.controls) {
        this.validateForm.controls[i].disable();
      }
      this.http.post(environment.SERVER_BASH_URL + '/account/account', this.validateForm.value).subscribe(() => {
        this.subject.next('true');
        this.close();
      });
    } else {
      for (const i in this.validateForm.controls) {
        this.validateForm.controls[i].markAsDirty();
      }
    }
  }

  close() {
    this.subject.destroy();
  }

  check(accountName) {
    if (accountName) {
      this.http.get(environment.SERVER_BASH_URL + '/account/' + accountName).subscribe((res: any) => {
        if (res.data > 0) {
          this.validateForm.controls.accountName.setErrors({unique: true});
        }
      });
    } else {
      this.validateForm.controls.accountName.setErrors({required: true});
    }
  }

  searchChange(searchText) {
    if (searchText) {
      const query = encodeURI(searchText);
      if (query) {
        this.http.get(environment.SERVER_BASH_URL + '/organization/list/' + query).subscribe((res: any) => {
          this.searchOptions = res.data;
        });
      }
    }
  }
}
